@@ -3,12 +3,13 @@ from __future__ import unicode_literals
 import json
 import warnings
 
+from django.contrib.sites.models import Site
 from django.core.exceptions import ValidationError
 from django.db.models import Model
 from django.utils import six
+from djblets.siteconfig.models import SiteConfiguration
 
 from djblets.db.fields import JSONField, JSONFormField
-from djblets.deprecation import RemovedInDjblets20Warning
 from djblets.testing.testcases import TestCase
 
 
@@ -39,27 +40,6 @@ class JSONFieldTests(TestCase):
         self.assertEqual(field.dumps(MyEncoder), '"What even is this?"')
         self.assertEqual(len(w), 0)
 
-    def test_init_with_custom_encoder_instance(self):
-        """Testing JSONField initialization with deprecated custom encoder
-        instance
-        """
-        class MyEncoder(json.JSONEncoder):
-            def default(self, o):
-                return 'What even is this?'
-
-        with warnings.catch_warnings(record=True) as w:
-            field = JSONField(encoder=MyEncoder())
-
-        self.assertEqual(field.dumps(MyEncoder), '"What even is this?"')
-        self.assertEqual(len(w), 1)
-
-        message = w[0].message
-        self.assertIsInstance(message, RemovedInDjblets20Warning)
-        self.assertEqual(six.text_type(message),
-                         'The encoder argument to JSONField has been '
-                         'replaced by the encoder_cls and encoder_kwargs '
-                         'arguments. Support for encoder is deprecated.')
-
     def test_init_with_dict_value(self):
         """Testing JSONField initialization with initial dict value"""
         class MyModel(Model):
@@ -148,14 +128,24 @@ class JSONFieldTests(TestCase):
         class MyModel(Model):
             myfield = JSONField()
 
-        message = (
-            "<class 'djblets.db.tests.test_json_field.MyModel'> is not a "
-            "supported value type."
-        )
+        message = "%r is not a supported value type." % MyModel
 
         with self.assertRaisesMessage(ValidationError, message):
             MyModel(myfield=MyModel())
 
+    def test_init_with_deferred(self):
+        """Testing JSONField initialization with deferred attribute"""
+        SiteConfiguration.objects.create(site=Site.objects.get_current())
+
+        # Saving the SiteConfiguration results in a cache clear, so re-fetch
+        # this in order to avoid a query below.
+        Site.objects.get_current()
+
+        # This should fetch just the SiteConfiguration, and not result in a
+        # fetch of settings in JSONField.post_init.
+        with self.assertNumQueries(1):
+            SiteConfiguration.objects.defer('settings').get(pk=1)
+
     def test_dumps_with_json_dict(self):
         """Testing JSONField with dumping a JSON dictionary"""
         result = self.field.dumps({'a': 1, 'b': 2})
@@ -235,6 +225,46 @@ class JSONFieldTests(TestCase):
                 'b': 2,
             })
 
+    def test_get_prep_value_with_string(self):
+        """Testing JSONField.get_prep_value with string value"""
+        self.assertEqual(
+            self.field.get_prep_value('{"a": 1, "b": 2}'),
+            '{"a": 1, "b": 2}')
+
+    def test_get_prep_value_with_dict(self):
+        """Testing JSONField.get_prep_value with dict value"""
+        self.assertEqual(
+            self.field.get_prep_value({
+                'a': 1,
+                'b': 2,
+            }),
+            '{"a": 1, "b": 2}')
+
+    def test_get_prep_value_with_none(self):
+        """Testing JSONField.get_prep_value with None value"""
+        self.assertIsNone(self.field.get_prep_value(None))
+
+    def test_to_python_with_string(self):
+        """Testing JSONField.to_python with string value"""
+        self.assertEqual(
+            self.field.to_python('{"a": 1, "b": 2}'),
+            {
+                'a': 1,
+                'b': 2,
+            })
+
+    def test_to_python_with_dict(self):
+        """Testing JSONField.to_python with dictionary value"""
+        self.assertEqual(
+            self.field.to_python({
+                'a': 1,
+                'b': 2,
+            }),
+            {
+                'a': 1,
+                'b': 2,
+            })
+
     def test_validate_with_valid_json_string(self):
         """Testing JSONField with validating a valid JSON string"""
         self.field.run_validators('{"a": 1, "b": 2}')
