@@ -2,12 +2,7 @@
 
 from __future__ import unicode_literals
 
-import warnings
-
-from django.template.loader import render_to_string
-
 from djblets.integrations.forms import IntegrationConfigForm
-from djblets.util.compat.django.template.loader import render_to_string
 
 
 class Integration(object):
