@@ -121,9 +121,9 @@ mail_settings_map = {
     'mail_host':                   'EMAIL_HOST',
     'mail_port':                   'EMAIL_PORT',
     'mail_host_user':              {'key': 'EMAIL_HOST_USER',
-                                    'deserialize_func': bytes},
+                                    'deserialize_func': str},
     'mail_host_password':          {'key': 'EMAIL_HOST_PASSWORD',
-                                    'deserialize_func': bytes},
+                                    'deserialize_func': str},
     'mail_use_tls':                'EMAIL_USE_TLS',
 }
 
