@@ -6,6 +6,7 @@ import json
 
 from django.test.utils import override_settings
 from django.test.client import RequestFactory
+from django.utils.encoding import force_text
 
 from djblets.testing.testcases import TestCase
 from djblets.webapi.errors import RATE_LIMIT_EXCEEDED
@@ -44,5 +45,5 @@ class WebAPIRateLimitTests(TestCase):
         self.assertEqual(response.status_code, 429)
         self.assertEqual(response['X-RateLimit-Limit'], '2')
 
-        rsp = json.loads(response.content)
+        rsp = json.loads(force_text(response.content))
         self.assertEqual(rsp['err']['code'], RATE_LIMIT_EXCEEDED.code)
